@@ -3,22 +3,18 @@
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE TypeFamilies #-}
+{-# OPTIONS_GHC -Wno-missing-export-lists #-}
+{-# OPTIONS_GHC -Wno-simplifiable-class-constraints #-}
 module Property.ReinforcementProps
-  ( prop_predicate_negative_not_counted
-  , prop_lazy_partial_force_concurrency
-  , prop_partial_order_interleaved_duplicates
-  ) where
+  where
 
 import Test.QuickCheck
 import Test.QuickCheck.Monadic (monadicIO, run, assert)
 import Control.Exception (try, SomeException, evaluate)
 import Control.Concurrent.Async (forConcurrently_)
 import UnliftIO (withRunInIO)
-import Control.Monad (forM_)
-import Control.Monad.IO.Class (liftIO)
-import Data.List (nub)
 import Test.MockCat hiding (any)
-import Test.MockCat (param)
 
 --------------------------------------------------------------------------------
 -- 1. Predicate negative: failing inputs raise & are not counted
@@ -26,8 +22,7 @@ import Test.MockCat (param)
 
 prop_predicate_negative_not_counted :: Property
 prop_predicate_negative_not_counted = forAll genVals $ \xs -> monadicIO $ do
-  m <- run $ createMock (expect even "even" |> True)
-  let f = stubFn m
+  f <- run $ mock (expect even "even" ~> True)
   outcomes <- run $ mapM (\x -> (try (evaluate (f x)) :: IO (Either SomeException Bool))) xs
   let evens = length (filter even xs)
       successes = length [ () | (x, Right _) <- zip xs outcomes, even x ]
@@ -40,8 +35,8 @@ prop_predicate_negative_not_counted = forAll genVals $ \xs -> monadicIO $ do
   assert (failures == odds)
   -- Successes count equals even inputs
   assert (successes == evens)
-  -- Applied count equals successes (only even)
-  run $ m `shouldApplyTimesToAnything` evens
+  -- Called count equals successes (only even)
+  run $ f `shouldBeCalled` times evens
   assert True
   where
     genVals = resize 60 $ listOf (arbitrary :: Gen Int)
@@ -54,14 +49,16 @@ prop_predicate_negative_not_counted = forAll genVals $ \xs -> monadicIO $ do
 class Monad m => ParLazyAction m where
   parLazy :: Int -> m Int
 
-makeMock [t|ParLazyAction|]
+makeAutoLiftMock [t|ParLazyAction|]
 
 prop_lazy_partial_force_concurrency :: Property
 prop_lazy_partial_force_concurrency = forAll genPlan $ \(arg, mask) -> monadicIO $ do
   let forcedCount = length (filter id mask)
   run $ runMockT $ do
     -- expectation: arg -> arg; count only forced executions
-    _parLazy (param arg |> arg) `applyTimesIs` forcedCount
+    _ <- _parLazy (param arg ~> arg)
+      `expects` do
+        called (times forcedCount)
     -- prepare thunks (NOT executed yet)
     let thunks = replicate (length mask) (parLazy arg)
     withRunInIO $ \runIn -> do
@@ -85,13 +82,12 @@ prop_lazy_partial_force_concurrency = forAll genPlan $ \(arg, mask) -> monadicIO
 prop_partial_order_interleaved_duplicates :: Property
 prop_partial_order_interleaved_duplicates = forAll genPair $ \(a,b) -> a /= b ==> monadicIO $ do
   -- Pattern a a b : [a,b] subsequence succeeds, [b,a] fails.
-  m <- run $ createMock $ cases [ param a |> True
-                                , param a |> True
-                                , param b |> True ]
-  let f = stubFn m
+  f <- run $ mock $ cases [ param a ~> True
+                                , param a ~> True
+                                , param b ~> True ]
   run $ f a `seq` f a `seq` f b `seq` pure ()
-  run $ m `shouldApplyInPartialOrder` [param a, param b]
-  e <- run $ (try (m `shouldApplyInPartialOrder` [param b, param a]) :: IO (Either SomeException ()))
+  run $ f `shouldBeCalled` inPartialOrderWith [param a, param b]
+  e <- run $ (try (f `shouldBeCalled` inPartialOrderWith [param b, param a]) :: IO (Either SomeException ()))
   case e of
     Left _  -> assert True
     Right _ -> assert False
