@@ -5,14 +5,13 @@ module Property.ScriptProps
 
 import Test.QuickCheck
 import Test.QuickCheck.Monadic (monadicIO, run, assert)
-import Test.MockCat (shouldApplyTimesToAnything, stubFn)
+import Test.MockCat (shouldBeCalled, times)
 import Property.Generators
 
--- | Property: executing a generated script produces exactly that many recorded applications.
+-- | Property: executing a generated script produces exactly that many recorded calls.
 prop_script_count_matches :: Property
 prop_script_count_matches = forAll scriptGen $ \scr@(Script xs) -> monadicIO $ do
-  m <- run $ buildUnaryMock scr
-  let f = stubFn m
+  f <- run $ buildUnaryMock scr
   run $ runScript f scr
-  run $ m `shouldApplyTimesToAnything` length xs
+  run $ f `shouldBeCalled` times (length xs)
   assert True
