@@ -9,6 +9,19 @@ import Test.MockCat.TypeClassTHSpec as TypeClassTH
 import Test.MockCat.PartialMockSpec as PartialMock
 import Test.MockCat.PartialMockTHSpec as PartialMockTH
 import Test.MockCat.ConcurrencySpec as Concurrency
+import Test.MockCat.StubSpec as Stub
+import Test.MockCat.Internal.MockRegistrySpec as Registry
+import Test.MockCat.MockTSpec as MockTSpec
+import Test.MockCat.TH.TypeUtilsSpec as THTypeUtils
+import Test.MockCat.TH.ContextBuilderSpec as THContextBuilder
+import Test.MockCat.TH.ClassAnalysisSpec as THClassAnalysis
+import Test.MockCat.TH.FunctionBuilderSpec as THFunctionBuilder
+import Test.MockCat.ShouldBeCalledSpec as ShouldBeCalled
+import Test.MockCat.ShouldBeCalledMockMSpec as ShouldBeCalledMockM
+import Test.MockCat.WithMockSpec as WithMock
+import Test.MockCat.ErrorDiffSpec as ErrorDiff
+import Test.MockCat.THCompareSpec as THCompare
+import ReadmeVerifySpec as ReadmeVerify
 import Test.QuickCheck (property)
 import qualified Property.ConcurrentCountProp as ConcurrencyProp
 import qualified Property.LazyEvalProp as LazyEvalProp
@@ -32,23 +45,35 @@ main = hspec $ do
     PartialMock.spec
     PartialMockTH.spec
     Concurrency.spec
+    Stub.spec
+    MockTSpec.spec
+    Registry.spec
+    THCompare.spec
+    THTypeUtils.spec
+    THContextBuilder.spec
+    THClassAnalysis.spec
+    THFunctionBuilder.spec
+    ShouldBeCalled.spec
+    ShouldBeCalledMockM.spec
+    WithMock.spec
+    ErrorDiff.spec
+    ReadmeVerify.spec
     describe "Property Concurrency" $ do
       it "total apply count is preserved across threads" $ property ConcurrencyProp.prop_concurrent_total_apply_count
     describe "Property Lazy Evaluation" $ do
       it "unforced stub action is not counted" $ property LazyEvalProp.prop_lazy_unforced_not_counted
       it "forced stub action is counted" $ property LazyEvalProp.prop_lazy_forced_counted
     describe "Property Script Generator" $ do
-      it "script count matches recorded applications" $ property ScriptProps.prop_script_count_matches
+      it "script count matches recorded calls" $ property ScriptProps.prop_script_count_matches
     describe "Property Order / PartialOrder" $ do
       it "in-order script succeeds" $ property OrderProps.prop_inorder_succeeds
       it "adjacent swap fails order verification" $ property OrderProps.prop_adjacent_swap_fails
       it "subset partial order succeeds" $ property OrderProps.prop_partial_order_subset_succeeds
       it "reversed pair fails partial order" $ property OrderProps.prop_partial_order_reversed_pair_fails
-    describe "Property Additional (Predicate / Multi-case / Isolation / Unused / Duplicates)" $ do
+    describe "Property Additional (Predicate / Multi-case / Isolation / Duplicates)" $ do
       it "predicate param counts match" $ property AdditionalProps.prop_predicate_param_match_counts
       it "multi-case progression saturates" $ property AdditionalProps.prop_multicase_progression
       it "runMockT isolation of counts" $ property AdditionalProps.prop_runMockT_isolation
-      it "neverApply (unused) passes" $ property AdditionalProps.prop_neverApply_unused
       it "partial order with duplicates behaves" $ property AdditionalProps.prop_partial_order_duplicates
     describe "Property Reinforcement (Negative predicate / Partial force / Interleave)" $ do
       it "predicate negative not counted" $ property ReinforcementProps.prop_predicate_negative_not_counted
