@@ -4,7 +4,7 @@
 {-# OPTIONS_GHC -Wno-name-shadowing #-}
 module Test.MockCat.Impl (FileOperation, Finder) where
 
-import Test.MockCat.Definition
+import Test.MockCat.SharedSpecDefs
 import Data.Text (pack)
 import Prelude hiding (readFile, writeFile)
 import Control.Monad.Trans.Maybe
@@ -26,4 +26,9 @@ instance Monad m => FileOperation (ReaderT String m) where
 
 instance Finder Int String IO where
   findIds = pure [1 :: Int, 2 :: Int, 3 :: Int]
-  findById id = pure $ "{id: " <> show id <> "}"
\ No newline at end of file
+  findById id = pure $ "{id: " <> show id <> "}"
+
+-- Provide FinderNoImplicit fallback instance for tests that use explicit monadic returns
+instance FinderNoImplicit Int String IO where
+  findIdsNI = pure [1 :: Int, 2 :: Int, 3 :: Int]
+  findByIdNI i = pure $ "{id: " <> show i <> "}"
\ No newline at end of file
